@@ -6,6 +6,7 @@ from pydantic import BaseModel
 from watchmen_model.common import Auditable, BucketId, DataModel, FactorId, IndicatorId, InspectionId, UserBasedTuple
 from watchmen_utilities import ArrayHelper
 from .indicator import IndicatorAggregateArithmetic
+from .indicator_criteria import construct_indicator_criteria_list, IndicatorCriteria
 from .measure_method import MeasureMethod
 
 
@@ -118,7 +119,7 @@ def construct_time_range(a_range: Optional[Union[dict, InspectionTimeRange]]) ->
 		return None
 	elif isinstance(a_range, InspectionTimeRange):
 		return a_range
-	
+
 	range_type = a_range.get('type')
 	if range_type == InspectionTimeRangeType.YEAR:
 		return InspectionYearRange(**a_range)
@@ -183,9 +184,12 @@ class Inspection(UserBasedTuple, Auditable, BaseModel):
 	measureOnTime: MeasureMethod = None
 	# time measure on factor
 	measureOnTimeFactorId: FactorId = None
+	criteria: List[IndicatorCriteria] = []
 
 	def __setattr__(self, name, value):
 		if name == 'timeRanges':
 			super().__setattr__(name, construct_time_ranges(value))
+		elif name == 'criteria':
+			super().__setattr__(name, construct_indicator_criteria_list(value))
 		else:
 			super().__setattr__(name, value)
